function lines = linesHough(img,thr)
% adapted from the Matlab help

%thr= >0 <1: percentage of max peak to be used to threshold the matrix H.
%default: 0.8

%convert to gray level and check args
if size(img,3)>1
   imgGL = rgb2gray(img); 
else
   imgGL = img;
end
if nargin == 1
    thr = 0.8;
end

% extract edges
edges = edge(imgGL,'sobel'); 

[H,T,R] = hough(edges,'RhoResolution',0.5,'Theta',-90:0.5:89);

mesh(H);
% find peaks
P  = houghpeaks(H,1000,'threshold',thr*max(H(:)));
if isempty(P)
    error('no peak found, try to lower the threshold!');
end

% Find lines
lines = houghlines(edges,T,R,P,'FillGap',50,'MinLength',10);


%% visualization

figure('Name','Lines');

% display the original image
subplot(2,2,1);
imshow(img);
title('original image');

% display the line segments over the edges
subplot(2,2,3);imshow(edges); title('Hough lines');hold on
max_len = 0;
x = T(P(:,2)); y = R(P(:,1));
for k = 1:length(lines)
   xy = [lines(k).point1; lines(k).point2];
   plot(xy(:,1),xy(:,2),'LineWidth',2,'Color','green');

   % Plot beginnings and ends of lines
   plot(xy(1,1),xy(1,2),'x','LineWidth',2,'Color','yellow');
   plot(xy(2,1),xy(2,2),'x','LineWidth',2,'Color','red');
end
  
% display the hough matrix
subplot(2,2,[2 4]);
imshow(imadjust(mat2gray(H)),'XData',T,'YData',R,...
      'InitialMagnification','fit');
title('Hough transform');
xlabel('\theta'), ylabel('\rho');
axis on, axis normal, hold on;
plot(x,y,'s','color','red');
end % function